@@ -8,7 +8,7 @@ DBIx::TempDB - Create a temporary database
 
 =head1 VERSION
 
-0.09
+0.10
 
 =head1 SYNOPSIS
 
@@ -97,7 +97,7 @@ use constant KILL_SLEEP_INTERVAL => $ENV{DBIX_TEMP_DB_KILL_SLEEP_INTERVAL} || 2;
 use constant MAX_NUMBER_OF_TRIES => $ENV{DBIX_TEMP_DB_MAX_NUMBER_OF_TRIES} || 20;
 use constant MAX_OPEN_FDS => eval { use POSIX qw( sysconf _SC_OPEN_MAX ); sysconf(_SC_OPEN_MAX) } || 1024;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
 our %SCHEMA_DATABASE = (pg => 'postgres', mysql => 'mysql');
 my $N = 0;
 
@@ -173,19 +173,19 @@ sub dsn {
 
 =head2 execute
 
-  $self = $self->execute($sql);
+  $self = $self->execute(@sql);
 
-This method will execute the given C<$sql> statements in the temporary
+This method will execute a list of C<@sql> statements in the temporary
 SQL server.
 
 =cut
 
 sub execute {
-  my ($self, $sql) = @_;
-  my $dbh = DBI->connect($self->dsn);
+  my $self   = shift;
+  my $dbh    = DBI->connect($self->dsn);
   my $parser = $self->can("_parse_@{[$self->url->canonical_engine]}") || sub { $_[1] };
   local $dbh->{sqlite_allow_multiple_statements} = 1 if $self->url->canonical_engine eq 'sqlite';
-  $dbh->do($_) for $self->$parser($sql);
+  $dbh->do($self->$parser($_)) for @_;
   $self;
 }
 
@@ -535,7 +535,7 @@ sub _drop_from_double_forked_child {
 
 sub _parse_mysql {
   my ($self, $sql) = @_;
-  my ($new, $last, $delimiter) = (1, '', ';');
+  my ($new, $last, $delimiter) = (0, '', ';');
   my @commands;
 
   while (length($sql) > 0) {
@@ -582,8 +582,7 @@ sub _parse_mysql {
   }
 
   push @commands, $last if $last !~ /^\s*$/s;
-
-  return @commands;
+  return map { s/^\s+//; $_ } @commands;
 }
 
 sub _schema_dsn {
